@@ -6,7 +6,7 @@ from spikesorters.tests.common_tests import SorterCommonTestSuite
 
 
 # # This run several tests
-@pytest.mark.skipif(not SpykingcircusSorter.installed, reason='spykingcircus not installed')
+@pytest.mark.skipif(not SpykingcircusSorter.is_installed(), reason='spykingcircus not installed')
 class SpykingcircusCommonTestSuite(SorterCommonTestSuite, unittest.TestCase):
     SorterClass = SpykingcircusSorter
 
